==> nfc_read_write_plugin-1.0.0.tar.gz: example/android/app/src/main/java/com/nfc_read_write/nfc_read_write_plugin_example/MainActivity.java <==
package com.nfc_read_write.nfc_read_write_plugin_example;

import android.app.PendingIntent;
import android.content.Intent;
import android.content.IntentFilter;
import android.nfc.NfcAdapter;
import android.nfc.tech.NfcA;
import android.nfc.tech.NfcV;

import io.flutter.embedding.android.FlutterActivity;

public class MainActivity extends FlutterActivity {
    protected String[][] techList;
    protected IntentFilter[] intentFilters;
    protected PendingIntent pendingIntent;
    @Override
    protected void onResume() {



        techList = new String[][] { new String[] { NfcV.class.getName() },
                new String[] { NfcA.class.getName() } };
        intentFilters = new IntentFilter[] { new IntentFilter(NfcAdapter.ACTION_TECH_DISCOVERED), };
        // 创建一个 PendingIntent 对象, 这样Android系统就能在一个tag被检测到时定位到这个对象
        pendingIntent = PendingIntent.getActivity(this, 0,
                new Intent(this, getClass()).addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP), 0);
        NfcAdapter nfcAdapter = NfcAdapter.getDefaultAdapter(this);
        if (nfcAdapter!=null){
            nfcAdapter.enableForegroundDispatch(this, pendingIntent, intentFilters, techList);
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        super.onPause();

        NfcAdapter nfcAdapter = NfcAdapter.getDefaultAdapter(this);
        if (nfcAdapter!=null){
            nfcAdapter.enableForegroundDispatch(this, pendingIntent, intentFilters, techList);
        }
    }

}

==> nfc_read_write_plugin-1.0.1.tar.gz: example/android/app/src/main/java/com/nfc_read_write/nfc_read_write_plugin_example/MainActivity.java <==
package com.nfc_read_write.nfc_read_write_plugin_example;

import android.app.PendingIntent;
import android.content.Intent;
import android.content.IntentFilter;
import android.nfc.NfcAdapter;
import android.nfc.tech.MifareClassic;
import android.nfc.tech.NfcA;
import android.nfc.tech.NfcV;

import io.flutter.embedding.android.FlutterActivity;

public class MainActivity extends FlutterActivity {
    protected String[][] techList;
    protected IntentFilter[] intentFilters;
    protected PendingIntent pendingIntent;
    @Override
    protected void onResume() {
        techList = new String[][] { new String[] { NfcV.class.getName() },
                new String[] { NfcA.class.getName() } ,new String[] { MifareClassic.class.getName() }};
        intentFilters = new IntentFilter[] { new IntentFilter(NfcAdapter.ACTION_TECH_DISCOVERED), };
        // 创建一个 PendingIntent 对象, 这样Android系统就能在一个tag被检测到时定位到这个对象
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.S) {
            pendingIntent = PendingIntent.getActivity(this, 123, new Intent(this, getClass()).addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP), PendingIntent.FLAG_IMMUTABLE);
        } else {
            pendingIntent = PendingIntent.getActivity(this, 123, new Intent(this, getClass()).addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP), PendingIntent.FLAG_ONE_SHOT);
        }
        NfcAdapter nfcAdapter = NfcAdapter.getDefaultAdapter(this);
        if (nfcAdapter!=null){
            nfcAdapter.enableForegroundDispatch(this, pendingIntent, intentFilters, techList);
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        super.onPause();

        NfcAdapter nfcAdapter = NfcAdapter.getDefaultAdapter(this);
        if (nfcAdapter!=null){
            nfcAdapter.enableForegroundDispatch(this, pendingIntent, intentFilters, techList);
        }
    }

}
